"use client";

import Image from "next/image";

import { Card, CardContent } from "@/components/ui/card";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { useLocale } from "next-intl";


export default function ServicesList() {
	const locale = useLocale() as Locale;
	const isRTL = locale === "ar";

	const { texts } = useBasicInfo();



	return (
		<section className="container mx-auto max-w-7xl px-4 py-16 lg:px-8">
			<div className="grid gap-6 md:grid-cols-2 lg:grid-cols-3">
				{texts?.about_company_features?.map(({ image, icon, text, description }: any, index: number) => (
					<Card
						key={index}
						className="group relative overflow-hidden border-none bg-[#f0ebff]"
					>
						<div className="h-[205px] w-full">
							<Image src={ImageBaseUrl + image} alt="" width={500} height={500} className="object-fill w-full h-auto" />
						</div>
						{/* Content */}
						<CardContent
							className={cn(
								"relative mt-auto min-h-[200px] p-6 transition-all duration-300 group-hover:bg-white",
								isRTL ? "text-right" : "text-left"
							)}
						>
							<div className="mb-4">
								<div
									className={cn(
										"inline-flex h-12 w-12 items-center justify-center rounded-lg bg-[#2895C8]",
										isRTL ? "float-right ml-4" : "float-left mr-4"
									)}
								>
									<Image
										src={ImageBaseUrl + icon}
										alt=""
										width={24}
										height={24}
										className="text-white"
									/>
								</div>
								<h3 className="text-xl font-bold text-[#2895C8]">
									{text?.[locale]}
								</h3>
							</div>
							<p className="text-gray-600">{description?.[locale]}</p>
						</CardContent>
					</Card>
				))}
			</div>
		</section>
	);
}
